@@ -21,9 +21,23 @@ import hashlib
 import json
 
 from lxml import etree
+from lxml.html import soupparser
 from lxml.html.soupparser import parse
 from django.core.management.base import BaseCommand
 from django.template.loader import get_template
+from BeautifulSoup import (
+        BeautifulSoup, Tag, Comment, ProcessingInstruction, NavigableString,
+        Declaration, CData)
+_DECLARATION_OR_DOCTYPE = Declaration
+
+soupparser.BeautifulSoup = BeautifulSoup
+soupparser.Tag = Tag
+soupparser.Comment = Comment
+soupparser.ProcessingInstruction = ProcessingInstruction
+soupparser.NavigableString = NavigableString
+soupparser.Declaration = Declaration
+soupparser.CData = CData
+soupparser._DECLARATION_OR_DOCTYPE = _DECLARATION_OR_DOCTYPE
 
 from Zephyrus.boilerplate.management.commands import (
     TEMPLATES_DIR_PATH, STATIC_DIR_PATH)
@@ -134,7 +148,7 @@ class Command(BaseCommand):
                         continue
 
                     # etree ----------------------------------------------------
-                    page = parse(f)
+                    page = parse(f, beautifulsoup=BeautifulSoup)
                     
                     # replace word
                     self.changeWordToMd5(page)
